<center>
<img src="https://edanalytics.github.io/earthmover/assets/ea-earthmover.png" alt="earthmover" />
</center>

`earthmover` transforms collections of tabular source data (flat files, FTP files, database tables/queries) into text-based (JSONL, XML) data via YAML configuration.

Learn more at [the `earthmover` documentation site](https://edanalytics.github.io/earthmover).
